@@ -27,8 +27,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <glade/glade.h>
-
 #include "gsd-media-keys-window.h"
 
 #define DIALOG_TIMEOUT 2000     /* dialog timeout in ms */
@@ -169,16 +167,6 @@ window_set_icon_name (GsdMediaKeysWindow *window,
                                       name, GTK_ICON_SIZE_DIALOG);
 }
 
-static void
-window_set_icon_file (GsdMediaKeysWindow *window,
-                      const char         *path)
-{
-        if (window->priv->image == NULL)
-                return;
-
-        gtk_image_set_from_file (window->priv->image, path);
-}
-
 static void
 action_changed (GsdMediaKeysWindow *window)
 {
@@ -196,7 +184,7 @@ action_changed (GsdMediaKeysWindow *window)
                         break;
                 case GSD_MEDIA_KEYS_WINDOW_ACTION_EJECT:
                         volume_controls_set_visible (window, FALSE);
-                        window_set_icon_file (window, PIXMAPDIR "/acme-eject.png");
+                        window_set_icon_name (window, "media-eject");
                         break;
                 default:
                         break;
@@ -807,7 +795,7 @@ on_expose_event (GtkWidget          *widget,
         cairo_paint (cr);
 
         /* draw a box */
-        curved_rectangle (cr, 0, 0, width, height, height / 10);
+        curved_rectangle (cr, 0.5, 0.5, width-1, height-1, height / 10);
         color = GTK_WIDGET (window)->style->bg [GTK_STATE_NORMAL];
         r = (float)color.red / 65535.0;
         g = (float)color.green / 65535.0;
@@ -953,21 +941,29 @@ gsd_media_keys_window_init (GsdMediaKeysWindow *window)
 
                 window->priv->fade_out_alpha = 1.0;
         } else {
-        	GladeXML *xml;
+                GtkBuilder *builder;
+                gchar *objects[] = {"acme_frame", NULL};
                 GtkWidget *frame;
 
-                xml = glade_xml_new (GLADEDIR "/acme.glade", "acme_frame", NULL);
+                builder = gtk_builder_new ();
+                gtk_builder_add_objects_from_file (builder,
+                                                   GTKBUILDERDIR "/acme.ui",
+                                                   objects,
+                                                   NULL);
 
-                window->priv->image = GTK_IMAGE (glade_xml_get_widget (xml, "acme_image"));
-                window->priv->progress = glade_xml_get_widget (xml, "acme_volume_progressbar");
-                frame = glade_xml_get_widget (xml, "acme_frame");
-
-                g_object_unref (xml);
+                window->priv->image = GTK_IMAGE (gtk_builder_get_object (builder, "acme_image"));
+                window->priv->progress = GTK_WIDGET (gtk_builder_get_object (builder, "acme_volume_progressbar"));
+                frame = GTK_WIDGET (gtk_builder_get_object (builder,
+                                                            "acme_frame"));
 
                 if (frame != NULL) {
                         gtk_container_add (GTK_CONTAINER (window), frame);
                         gtk_widget_show_all (frame);
                 }
+
+                /* The builder needs to stay alive until the window
+                   takes ownership of the frame (and its children)  */
+                g_object_unref (builder);
         }
 }
 
